@@ -69,17 +69,24 @@ test_succeeds("Can run build(hp) and plot_tuner()", {
   
   if (!Sys.info()[1] %in% 'Windows') {
     
-    tuner2 %>% fit_tuner(x_data, y_data, epochs = 5, validation_data = list(x_data2,y_data2))
-    
-    res = tuner2 %>% get_best_models(1) %>% .[[1]] %>% capture.output() %>% .[1]
-    
-    testthat::expect_output(print(res),regexp ='Model')
-    
-    tuner2 %>% results_summary(12)
-    
-    p1=kerastuneR::plot_tuner(tuner2)
-    p2=kerastuneR::plot_tuner(tuner2,height = 500, width = 500)
-    
+    if (tensorflow::tf_version() == c('2.0') | tensorflow::tf_version() == c('2.1')) {
+      
+      tensorboardd = TensorBoard()
+      
+      tuner2 %>% fit_tuner(x_data, y_data, epochs = 5, validation_data = list(x_data2,y_data2), callbacks=list(tensorboardd))
+      
+      res = tuner2 %>% get_best_models(1) %>% .[[1]] %>% capture.output() %>% .[1]
+      
+      testthat::expect_output(print(res),regexp ='Model')
+      
+      tuner2 %>% results_summary(12)
+      
+      p1=kerastuneR::plot_tuner(tuner2, type = 'echarts4r')
+      p2=kerastuneR::plot_tuner(tuner2,height = 500, width = 500)
+      
+      extract_model = tuner2 %>% get_best_models(1) %>% .[[1]]
+      
+    }
     
   }
 })
